==> illuminaMousev2BeadID.db_1.1.3.tar.gz: illuminaMousev2BeadID.db/man/illuminaMousev2BeadID_dbconn.Rd <==
\name{illuminaMousev2BeadID_dbconn}

\alias{illuminaMousev2BeadID_dbconn}
\alias{illuminaMousev2BeadID_dbfile}
\alias{illuminaMousev2BeadID_dbschema}
\alias{illuminaMousev2BeadID_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaMousev2BeadID_dbconn()
  illuminaMousev2BeadID_dbfile()
  illuminaMousev2BeadID_dbschema(file="", show.indices=FALSE)
  illuminaMousev2BeadID_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaMousev2BeadID_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{illuminaMousev2BeadID_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{illuminaMousev2BeadID_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaMousev2BeadID_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaMousev2BeadID_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaMousev2BeadID_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{illuminaMousev2BeadID_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaMousev2BeadID_dbschema}: none (invisible \code{NULL}).

  \code{illuminaMousev2BeadID_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaMousev2BeadID_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaMousev2BeadID_dbconn() was created with:
  dbConnect(SQLite(), dbname=illuminaMousev2BeadID_dbfile(), cache_size=64000, synchronous=0)

  illuminaMousev2BeadID_dbschema()

  illuminaMousev2BeadID_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> illuminaMousev2BeadID.db_1.4.0.tar.gz: illuminaMousev2BeadID.db/man/illuminaMousev2BeadID_dbconn.Rd <==

\name{illuminaMousev2BeadID_dbconn}

\alias{illuminaMousev2BeadID_dbconn}
\alias{illuminaMousev2BeadID_dbfile}
\alias{illuminaMousev2BeadID_dbschema}
\alias{illuminaMousev2BeadID_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  illuminaMousev2BeadID_dbconn()
  illuminaMousev2BeadID_dbfile()
  illuminaMousev2BeadID_dbschema(file="", show.indices=FALSE)
  illuminaMousev2BeadID_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{illuminaMousev2BeadID_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{illuminaMousev2BeadID_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{illuminaMousev2BeadID_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{illuminaMousev2BeadID_dbschema} prints the schema definition of the
  package annotation DB.

  \code{illuminaMousev2BeadID_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{illuminaMousev2BeadID_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{illuminaMousev2BeadID_dbfile}: a character string with the path to the
  package annotation DB.

  \code{illuminaMousev2BeadID_dbschema}: none (invisible \code{NULL}).

  \code{illuminaMousev2BeadID_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "probes" table:
  dbGetQuery(illuminaMousev2BeadID_dbconn(), "SELECT COUNT(*) FROM probes")

  ## The connection object returned by illuminaMousev2BeadID_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=illuminaMousev2BeadID_dbfile(), cache_size=64000,
  synchronous=0)

  illuminaMousev2BeadID_dbschema()

  illuminaMousev2BeadID_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
